@@ -163,5 +163,5 @@ class Importer(BaseAction):
         if self.options.retry_count:
             self.log.info("Looking for errors to auto-retry")
             self.env.resolve_errors(
-                self.retry_count,
+                self.options.retry_count,
                 self.options.timeout - time.time() - self.start_time)
