@@ -79,7 +79,7 @@ class Deployment(object):
                 expanded.append((k, c))
             by_weight = rels.setdefault(v.get('weight', 0), [])
             by_weight.extend(expanded)
-        for k in sorted(rels):
+        for k in sorted(rels, reverse=True):
             for r in rels[k]:
                 if check(*r):
                     yield r
@@ -132,6 +132,8 @@ class Deployment(object):
             for svc_name, svc_data in self.data['services'].items():
                 charm = self.get_charm_for(svc_name)
                 if k in charm.config:
+                    if 'options' not in svc_data:
+                        svc_data['options'] = {}
                     svc_data['options'][k] = v
                     found = True
             if not found:
