@@ -82,7 +82,7 @@ class BaseEnvironment(object):
                     repo = "."
                 params.extend(["--repository=%s" % repo])
             if force_machine is not None:
-                params.extend["--force-machine=%d" % force_machine]
+                params.extend(["--to=%d" % force_machine])
 
             params.extend([charm_url, name])
             self._check_call(
