@@ -10,8 +10,9 @@ from jujuclient import Environment as EnvironmentClient, UnitErrors, EnvError
 
 class GoEnvironment(BaseEnvironment):
 
-    def __init__(self, name, endpoint=None):
+    def __init__(self, name, options=None, endpoint=None):
         self.name = name
+        self.options = options
         self.api_endpoint = endpoint
         self.client = None
 
