@@ -18,7 +18,8 @@ class Service(object):
 
     @property
     def force_machine(self):
-        return self.svc_data.get('force-machine')
+        return self.svc_data.get('to') or self.svc_data.get(
+            'force-machine')
 
     @property
     def expose(self):
